use bevy_app::App;
use engine_render::RenderPlugin;
use engine_vulkan::{VulkanConfig, VulkanPlugin};
use engine_window::{WindowPlugin, config::WindowConfig};
use vulkano::device::{DeviceExtensions, DeviceFeatures};

pub fn init(app: &mut App) {
    let window_config = WindowConfig {
        title: "Rust ASH Test".to_string(),
        width: 800,
        height: 600,
    };

    let device_extensions = DeviceExtensions {
        khr_dynamic_rendering: true,
        ..Default::default()
    };

    let device_features = DeviceFeatures {
        dynamic_rendering: true,
        ..Default::default()
    };

    let vulkan_config = VulkanConfig {
        instance_layers: vec![String::from("VK_LAYER_KHRONOS_validation")],
        device_extensions,
        device_features,
        ..Default::default()
    };

    app.add_plugins((
        WindowPlugin { window_config },
        VulkanPlugin { vulkan_config },
        RenderPlugin,
    ));

    // app.get_sub_app_mut(RenderApp)
    //     .expect("Failed to get RenderApp. Check is RenderPlugin is added.")
    //     .add_systems(Render, test_system.in_set(RenderSystems::Prepare));
}

// fn test_system(vulkan_device: Res<VulkanDevice>, vulkan_graphics_queue: Res<VulkanGraphicsQueue>) {
//     log::trace!("vulkan_device: {:?}", vulkan_device.0);
//     log::trace!("vulkan_graphics_queue: {:?}", vulkan_graphics_queue.0);
// }
